''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' check_fileage.vbs v1.0 2014-07-16
' EasyNagios.com
' This is a NSClient++ addon script for Nagios that will check specific file age. 
' Returns Warning or Critical if file is older than specified minutes.
' $ARG1$ : The file path eg. c:/temp/watchme.log  *** this must be a 8.3 file format, if there is any space, it won't work.
' $ARG2$ : Warning level in minutes
' $ARG3$ : Criticl level in minutes

' Setup : 
' ============================== 
' 1. copy the vbscript to NSClient/script folder 

' 2. edit nsclient.ini and add the follow segment 
' [/settings/external scripts/scripts] 
' check_fileage=cscript.exe //nologo //T:30 scripts\\check_fileage.vbs $ARG1$ $ARG2$ $ARG3$

' 3. create a new command in nagios 
' define command{
'         command_name  check_fileage
'         command_line  $USER1$/check_nrpe -H $HOSTADDRESS$ -t 30 -u -c check_fileage -a $ARG1$ $ARG2$ $ARG3$
'         }

' 4. create your nagios service 
' 	define service{ 
' 		use generic-service 
' 		host_name TEST_HOST 
' 		service_description -check file age 
' 		check_command check_fileage!c:/temp/watchme.log!10!20
' 		} 

' don't forget to reload nagios and restart nsclient. 

''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''


If Wscript.Arguments.Count <> 3	Then
	Wscript.Echo "CRITICAL: Usage: myvbs.vbs <filename> <warning_in_min> <critical_in_min>"
	Wscript.Quit(2) 
End If

Dim objFS, strFile, intWarn, intCrit, ddFileDate
Set objFS = CreateObject("Scripting.FileSystemObject")
strFile = Wscript.Arguments.Item(0)
intWarn = Wscript.Arguments.Item(1)
intCrit = Wscript.Arguments.Item(2)

If objFS.FileExists(strFile) Then
	Set objFile = objFS.GetFile(strFile)
	Dim dFileDate, intFileAge
	dFileDate = objFile.DateLastModified 
	intFileAge = DateDiff("s",dFileDate,Now())
	
	If intFileAge > intCrit * 60 Then
		Wscript.Echo "CRITICAL: " & strFile & " is older than " & intCrit &" minutes. Last modified: " & dFileDate & "."
		Wscript.Quit(2)
	ElseIf intFileAge > intWarn * 60 Then
		Wscript.Echo "WARNING: " & strFile & " is older than " & intWarn &" minutes. Last modified: " & dFileDate & "."
		Wscript.Quit(1)
	Else
		Wscript.Echo "OK: " & strFile & " is " & Int(intFileAge / 60) &" minutes old. Last modified: " & dFileDate & "."
		Wscript.Quit(0)
	End If
Else
	 Wscript.Echo "CRITICAL: " & strFile &" does not exist."
	 Wscript.Quit(2) 
End If

